# Install

Please follow the supervisor deployment guide in the official [DP3 documentation](https://cesnet.github.io/dp3/install).

## Supervisord

It is recommended to run DP3 app components under [supervisord](http://supervisord.org/).

There are example configuration files for supervisor.
Replace `{{DP3_APP}}` with the actual name of your application.
